@@ -27,6 +27,47 @@
 
 #include "gpm-common.h"
 
+/**
+ * gpm_percent_to_discrete:
+ * @percentage: The percentage to convert
+ * @levels: The number of discrete levels
+ *
+ * We have to be carefull when converting from %->discrete as precision is very
+ * important if we want the highest value.
+ *
+ * Return value: The discrete value for this percentage.
+ **/
+guint
+gpm_percent_to_discrete (guint percentage,
+			 guint levels)
+{
+	/* check we are in range */
+	if (percentage > 100) {
+		return levels;
+	}
+	return ((gfloat) percentage * (gfloat) (levels - 1)) / 100.0f;
+}
+
+/**
+ * gpm_discrete_to_percent:
+ * @hw: The discrete level
+ * @levels: The number of discrete levels
+ *
+ * We have to be carefull when converting from discrete->%.
+ *
+ * Return value: The percentage for this discrete value.
+ **/
+guint
+gpm_discrete_to_percent (guint discrete,
+			 guint levels)
+{
+	/* check we are in range */
+	if (discrete > levels) {
+		return 100;
+	}
+	return (guint) ((float) discrete * (100.0f / (float) (levels - 1)));
+}
+
 /**
  * gpm_warning_beep
  **/
@@ -39,22 +80,22 @@ gpm_warning_beep (void)
 
 /**
  * gpm_get_timestring:
- * @time: The time value to convert in seconds
+ * @time_secs: The time value to convert in seconds
  * @cookie: The cookie we are looking for
  *
  * Returns a localised timestring
  *
  * Return value: The time string, e.g. "2 hours 3 minutes"
  **/
-char *
-gpm_get_timestring (int time)
+gchar *
+gpm_get_timestring (guint time_secs)
 {
 	char* timestring = NULL;
 	gint  hours;
 	gint  minutes;
 
 	/* Add 0.5 to do rounding */
-	minutes = (int) ( ( time / 60.0 ) + 0.5 );
+	minutes = (int) ( ( time_secs / 60.0 ) + 0.5 );
 
 	if (minutes == 0) {
 		timestring = g_strdup_printf (_("Unknown time"));
