@@ -33,7 +33,7 @@ G_BEGIN_DECLS
 #define GPM_IS_GRAPH_WIDGET_CLASS(obj)	(G_TYPE_CHECK_CLASS_TYPE ((obj), EFF_TYPE_GRAPH_WIDGET))
 #define GPM_GRAPH_WIDGET_GET_CLASS	(G_TYPE_INSTANCE_GET_CLASS ((obj), GPM_TYPE_GRAPH_WIDGET, GpmGraphWidgetClass))
 
-#define GPM_GRAPH_WIDGET_COLOUR_CHARGING	GPM_GRAPH_WIDGET_COLOUR_DARK_BLUE
+#define GPM_GRAPH_WIDGET_COLOUR_CHARGING	GPM_GRAPH_WIDGET_COLOUR_BLUE
 #define GPM_GRAPH_WIDGET_COLOUR_DISCHARGING	GPM_GRAPH_WIDGET_COLOUR_DARK_RED
 #define GPM_GRAPH_WIDGET_COLOUR_CHARGED		GPM_GRAPH_WIDGET_COLOUR_GREEN
 #define GPM_GRAPH_WIDGET_LEGEND_SPACING		19
@@ -63,13 +63,19 @@ typedef enum {
 	GPM_GRAPH_WIDGET_COLOUR_LAST
 } GpmGraphWidgetColour;
 
+typedef enum {
+	GPM_GRAPH_WIDGET_SHAPE_CIRCLE,
+	GPM_GRAPH_WIDGET_SHAPE_SQUARE,
+	GPM_GRAPH_WIDGET_SHAPE_DIAMOND,
+	GPM_GRAPH_WIDGET_SHAPE_TRIANGLE,
+	GPM_GRAPH_WIDGET_SHAPE_LAST
+} GpmGraphWidgetShape;
+
 typedef enum {
 	GPM_GRAPH_WIDGET_EVENT_ON_AC,
 	GPM_GRAPH_WIDGET_EVENT_ON_BATTERY,
 	GPM_GRAPH_WIDGET_EVENT_SCREEN_DIM,
 	GPM_GRAPH_WIDGET_EVENT_SCREEN_RESUME,
-	GPM_GRAPH_WIDGET_EVENT_DPMS_OFF,
-	GPM_GRAPH_WIDGET_EVENT_DPMS_ON,
 	GPM_GRAPH_WIDGET_EVENT_SUSPEND,
 	GPM_GRAPH_WIDGET_EVENT_HIBERNATE,
 	GPM_GRAPH_WIDGET_EVENT_RESUME,
@@ -80,9 +86,11 @@ typedef enum {
 } GpmGraphWidgetEvent;
 
 typedef enum {
+	GPM_GRAPH_WIDGET_TYPE_INVALID,
 	GPM_GRAPH_WIDGET_TYPE_PERCENTAGE,
 	GPM_GRAPH_WIDGET_TYPE_TIME,
-	GPM_GRAPH_WIDGET_TYPE_RATE,
+	GPM_GRAPH_WIDGET_TYPE_POWER,
+	GPM_GRAPH_WIDGET_TYPE_VOLTAGE,
 	GPM_GRAPH_WIDGET_TYPE_LAST
 } GpmGraphWidgetAxisType;
 
@@ -116,8 +124,11 @@ void		 gpm_graph_widget_set_axis_x		(GpmGraphWidget	*graph,
 							 GpmGraphWidgetAxisType axis);
 void		 gpm_graph_widget_set_axis_y		(GpmGraphWidget	*graph,
 							 GpmGraphWidgetAxisType axis);
-const gchar *	 gpm_graph_widget_event_description	(GpmGraphWidgetEvent	 event);
-GpmGraphWidgetColour	 gpm_graph_widget_event_colour	(GpmGraphWidgetEvent	 event);
+const gchar *	 gpm_graph_widget_event_description	(GpmGraphWidgetEvent event);
+void		 gpm_graph_widget_get_event_visual		(GpmGraphWidgetEvent event,
+							 GpmGraphWidgetColour *colour,
+							 GpmGraphWidgetShape *shape);
+GpmGraphWidgetAxisType	 gpm_graph_widget_string_to_axis_type (const gchar	*type);
 
 G_END_DECLS
 
