@@ -27,13 +27,10 @@
 
 #include <string.h>
 #include <unistd.h>
-#include <popt.h>
-
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
-
 #include <libgnomeui/libgnomeui.h>
 #include <glade/glade.h>
 
@@ -43,144 +40,143 @@
 #include "gpm-debug.h"
 
 #include "gpm-manager.h"
-#include "gpm-manager-glue.h"
+#include "gpm-interface-manager.h"
 
 static void gpm_exit (GpmManager *manager);
 
-/** registers org.gnome.PowerManager on a connection
+/**
+ * gpm_object_register:
+ * @connection: What we want to register to
+ * @object: The GObject we want to register
  *
- *  @return			If we successfully registered the object
+ * Register org.gnome.PowerManager on the session bus.
+ * This function MUST be called before DBUS service will work.
  *
- *  @note	This function MUST be called before DBUS service will work.
- */
+ * Return value: success
+ **/
 static gboolean
 gpm_object_register (DBusGConnection *connection,
-		     GObject         *object)
+		     GObject	     *object)
 {
 	DBusGProxy *bus_proxy = NULL;
 	GError *error = NULL;
 	guint request_name_result;
+	gboolean ret;
 
 	bus_proxy = dbus_g_proxy_new_for_name (connection,
 					       DBUS_SERVICE_DBUS,
 					       DBUS_PATH_DBUS,
 					       DBUS_INTERFACE_DBUS);
-/*
- * Add this define hack until we depend on DBUS 0.60, as the
- * define names have changed.
- * should fix bug: http://bugzilla.gnome.org/show_bug.cgi?id=322435
- */
-#ifdef DBUS_NAME_FLAG_PROHIBIT_REPLACEMENT
-	/* add the legacy stuff for FC4 */
-	if (!dbus_g_proxy_call (bus_proxy, "RequestName", &error,
-		G_TYPE_STRING, GPM_DBUS_SERVICE,
-		G_TYPE_UINT, DBUS_NAME_FLAG_PROHIBIT_REPLACEMENT,
-		G_TYPE_INVALID,
-		G_TYPE_UINT, &request_name_result,
-		G_TYPE_INVALID)) {
-		g_warning ("Failed to acquire %s: %s", GPM_DBUS_SERVICE, error->message);
-		return FALSE;
-	}
-#else
-	if (!dbus_g_proxy_call (bus_proxy, "RequestName", &error,
-		G_TYPE_STRING, GPM_DBUS_SERVICE,
-		G_TYPE_UINT, 0,
-		G_TYPE_INVALID,
-		G_TYPE_UINT, &request_name_result,
-		G_TYPE_INVALID)) {
-		g_warning ("Failed to acquire %s: %s", GPM_DBUS_SERVICE, error->message);
-		return FALSE;
-	}
-#endif
 
- 	if (request_name_result != DBUS_REQUEST_NAME_REPLY_PRIMARY_OWNER)
+	ret = dbus_g_proxy_call (bus_proxy, "RequestName", &error,
+				 G_TYPE_STRING, GPM_DBUS_SERVICE,
+				 G_TYPE_UINT, 0,
+				 G_TYPE_INVALID,
+				 G_TYPE_UINT, &request_name_result,
+				 G_TYPE_INVALID);
+	if (error) {
+		gpm_debug ("ERROR: %s", error->message);
+		g_error_free (error);
+	}
+	if (ret == FALSE) {
+		/* abort as the DBUS method failed */
+		gpm_warning ("RequestName failed!");
 		return FALSE;
+	}
 
 	/* free the bus_proxy */
 	g_object_unref (G_OBJECT (bus_proxy));
 
+	/* already running */
+ 	if (request_name_result != DBUS_REQUEST_NAME_REPLY_PRIMARY_OWNER) {
+		return FALSE;
+	}
+
 	dbus_g_object_type_install_info (GPM_TYPE_MANAGER, &dbus_glib_gpm_manager_object_info);
 	dbus_g_connection_register_g_object (connection, GPM_DBUS_PATH, object);
 
 	return TRUE;
 }
 
+/**
+ * gpm_exit:
+ * @manager: This manager class instance
+ **/
 static void
 gpm_exit (GpmManager *manager)
 {
 	gpm_stock_icons_shutdown ();
-
 	gpm_debug_shutdown ();
-	g_object_unref (manager);
 	exit (0);
 }
 
-static void
-gpm_critical_error (const char *content)
+/**
+ * timed_exit_cb:
+ * @loop: The main loop
+ *
+ * Exits the main loop, which is helpful for valgrinding g-p-m.
+ *
+ * Return value: FALSE, as we don't want to repeat this action.
+ **/
+static gboolean
+timed_exit_cb (GMainLoop *loop)
 {
-	GtkWidget *dialog;
-	dialog = gtk_message_dialog_new_with_markup (NULL,
-						     GTK_DIALOG_MODAL,
-						     GTK_MESSAGE_WARNING,
-						     GTK_BUTTONS_CLOSE,
-						     "<span size='larger'><b>%s</b></span>",
-						     GPM_NAME);
-	gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog),
-						    content);
-	/* we close the gtk lopp when the user clicks close */
-	g_signal_connect_swapped (dialog,
-				  "response",
-				  G_CALLBACK (gtk_main_quit),
-				  NULL);
-	gtk_window_present (GTK_WINDOW (dialog));
-	/* we wait here for user to click close */
-	gtk_main();
+	g_main_loop_quit (loop);
+	return FALSE;
 }
 
-/** Main entry point
- *
- *  @param	argc		Number of arguments given to program
- *  @param	argv		Arguments given to program
- *  @return			Return code
- */
+/**
+ * main:
+ **/
 int
 main (int argc, char *argv[])
 {
-	gint             i;
-	GMainLoop       *loop;
-	GnomeClient     *master;
+	GMainLoop *loop;
+	GnomeClient *master;
 	GnomeClientFlags flags;
 	DBusGConnection *system_connection;
 	DBusGConnection *session_connection;
-	gboolean         verbose = FALSE;
-	gboolean         no_daemon;
-	GpmManager      *manager = NULL;
-	GError          *error = NULL;
+	gboolean verbose = FALSE;
+	gboolean no_daemon = FALSE;
+	gboolean timed_exit = FALSE;
+	GpmManager *manager = NULL;
+	GError *error = NULL;
+	GOptionContext *context;
+ 	GnomeProgram *program;
+	char **debugoptions = NULL;
+	int i;
 
-	struct poptOption options[] = {
-		{ "no-daemon", '\0', POPT_ARG_NONE, NULL, 0,
+	const GOptionEntry options[] = {
+		{ "no-daemon", '\0', 0, G_OPTION_ARG_NONE, &no_daemon,
 		  N_("Do not daemonize"), NULL },
-		{ "verbose", '\0', POPT_ARG_NONE, NULL, 0,
+		{ "verbose", '\0', 0, G_OPTION_ARG_NONE, &verbose,
 		  N_("Show extra debugging information"), NULL },
-		{ NULL, '\0', 0, NULL, 0, NULL, NULL }
+		{ "timed-exit", '\0', 0, G_OPTION_ARG_NONE, &timed_exit,
+		  N_("Exit after a small delay (for debugging)"), NULL },
+		{ "debug", '\0', 0, G_OPTION_ARG_STRING_ARRAY, &debugoptions,
+		  N_("Debug specific files, e.g. power"), NULL },
+		{ NULL}
 	};
 
-	i = 0;
-	options[i++].arg = &no_daemon;
-	options[i++].arg = &verbose;
+	context = g_option_context_new (_("GNOME Power Manager"));
 
-	no_daemon = FALSE;
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init (argv[0], VERSION,
-			    LIBGNOMEUI_MODULE, argc, argv,
-			    GNOME_PROGRAM_STANDARD_PROPERTIES,
-			    GNOME_PARAM_POPT_TABLE, options,
-			    GNOME_PARAM_HUMAN_READABLE_NAME, GPM_NAME,
-			    NULL);
+	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+
+	program = gnome_program_init (argv[0], VERSION,
+			   	      LIBGNOMEUI_MODULE, argc, argv,
+			    	      GNOME_PROGRAM_STANDARD_PROPERTIES,
+			    	      GNOME_PARAM_GOPTION_CONTEXT, context,
+			    	      GNOME_PARAM_HUMAN_READABLE_NAME, GPM_NAME,
+			    	      NULL);
 
 	master = gnome_master_client ();
 	flags = gnome_client_get_flags (master);
 
+
 	if (flags & GNOME_CLIENT_IS_CONNECTED) {
 		/* We'll disable this as users are getting constant crashes */
 		/* gnome_client_set_restart_style (master, GNOME_RESTART_IMMEDIATELY);*/
@@ -193,21 +189,24 @@ main (int argc, char *argv[])
 		g_thread_init (NULL);
 	dbus_g_thread_init ();
 
-	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain (GETTEXT_PACKAGE);
-
 	gpm_debug_init (verbose);
 
+	/* Add all of the options specified on the --debug line */
+	if (debugoptions) {
+		for (i = 0; debugoptions[i]; i++) {
+			gpm_add_debug_option (debugoptions[i]);
+		}
+	}
+
 	/* check dbus connections, exit if not valid */
 	system_connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
 	if (error) {
 		gpm_warning ("%s", error->message);
 		g_error_free (error);
-		gpm_critical_error ("This program cannot start until you start the dbus "
-				    "<i>system</i> service.\n"
-				    "It is <b>strongly recommended</b> you reboot your compter "
-				    "after starting messagebus.");
+		gpm_critical_error ("This program cannot start until you start "
+				    "the dbus system service.\n"
+				    "It is <b>strongly recommended</b> you reboot "
+				    "your computer after starting this service.");
 		/* abort at this point */
 		exit (1);
 	}
@@ -217,7 +216,7 @@ main (int argc, char *argv[])
 		gpm_warning ("%s", error->message);
 		g_error_free (error);
 		gpm_critical_error ("This program cannot start until you start the "
-				    "dbus <i>session</i> service.\n\n"
+				    "dbus session service.\n\n"
 				    "This is usually started automatically in X "
 				    "or gnome startup when you start a new session.");
 		/* abort at this point */
@@ -225,11 +224,11 @@ main (int argc, char *argv[])
 	}
 
 	if (! gpm_stock_icons_init()) {
-		g_error ("Cannot continue without stock icons");
+		gpm_critical_error ("Cannot continue without stock icons");
 	}
 
 	if (! no_daemon && daemon (0, 0)) {
-		g_error ("Could not daemonize: %s", g_strerror (errno));
+		gpm_critical_error ("Could not daemonize: %s", g_strerror (errno));
 	}
 
 	manager = gpm_manager_new ();
@@ -243,9 +242,20 @@ main (int argc, char *argv[])
 
 	loop = g_main_loop_new (NULL, FALSE);
 
+	/* Only timeout and close the mainloop if we have specified it
+	 * on the command line */
+	if (timed_exit) {
+		g_timeout_add (1000 * 20, (GSourceFunc) timed_exit_cb, loop);
+	}
+
 	g_main_loop_run (loop);
 
-	gpm_exit (manager);
+	gpm_stock_icons_shutdown ();
+	gpm_debug_shutdown ();
+
+	g_object_unref (manager);
+	g_object_unref (program);
+	g_option_context_free (context);
 
 	return 0;
 }
